pub enum NetToEmbedderMsg {
SelectFiles(EmbedderControlId, FilePickerRequest, Sender<Option<Vec<PathBuf>>>),
WebResourceRequested(Option<WebViewId>, WebResourceRequest, UnboundedSender<WebResourceResponseMsg>),
RequestAuthentication(WebViewId, ServoUrl, bool, Sender<Option<AuthenticationResponse>>),
EmbedderGetCookiesForUrlResponse(CookieOperationId, Vec<Cookie<'static>>),
EmbedderSetCookieForUrlResponse(CookieOperationId),
}Expand description
Messages sent from the network threads to the embedder.
Variants
SelectFiles(EmbedderControlId, FilePickerRequest, Sender<Option<Vec<PathBuf>>>)
Open file dialog to select files. Set boolean flag to true allows to select multiple files.
WebResourceRequested(Option<WebViewId>, WebResourceRequest, UnboundedSender<WebResourceResponseMsg>)
RequestAuthentication(WebViewId, ServoUrl, bool, Sender<Option<AuthenticationResponse>>)
Request authentication for a load or navigation from the embedder.
EmbedderGetCookiesForUrlResponse(CookieOperationId, Vec<Cookie<'static>>)
Response to a [CoreResourceMsg::EmbedderGetCookiesForUrl] request.
EmbedderSetCookieForUrlResponse(CookieOperationId)
Response to a [CoreResourceMsg::EmbedderSetCookieForUrl] request.